require 'spec_helper'

describe LinkedPosts do
  before :each do
    @posts = []
    0.upto(3) do |n|
      post = stub "post #{n}"
      post.stub!(:slug).and_return "2011/03/02/post#{n}"
      @posts << post
    end
  end
  
  context 'post in the middle of list of posts' do
    before :each do
      @linked_posts = LinkedPosts.new @posts
      @linked_posts.slug = '2011/03/02/post2'
    end
  
    it 'should return current post' do
      @linked_posts.current.should  == @posts[2]
    end
  
    it 'should return previous post' do
      @linked_posts.previous_post.should == @posts[3]
    end
    
    it 'should return next post' do
      @linked_posts.next_post.should == @posts[1]
    end
  end
  
  context 'edge of list' do
    before :each do
      @linked_posts = LinkedPosts.new @posts
    end
    
    it 'should return nil for previous post when at the oldest post' do
      @linked_posts.slug = '2011/03/02/post3'
      @linked_posts.previous_post.should == nil
    end
    
    it 'should return nil for next post when at latest post' do
      @linked_posts.slug = '2011/03/02/post0'
      @linked_posts.next_post.should == nil
    end
  end
end