require 'spec_helper'
require 'nokogiri'

describe String do
  let :html do
    %{
      <html>
        <body>
          <img src='/images/lisa.jpg' />
          <a href='/daily-gift-ideas?page=2' />
        </body>
      </html>
    }
  end
  
  it 'should convert relative images to absolute' do
    absolute_html = html.to_absolute('http://www.outsideofthebox.com.au')
    Nokogiri::HTML(absolute_html).css('img').first['src'].should == 'http://www.outsideofthebox.com.au/images/lisa.jpg'
  end
  
  it 'should convert relative links to absolute' do
    absolute_html = html.to_absolute('http://www.outsideofthebox.com.au')
    Nokogiri::HTML(absolute_html).css('a').first['href'].should == 'http://www.outsideofthebox.com.au/daily-gift-ideas?page=2'
  end
  
  it 'should add path to base path when file scheme' do
    absolute_html = html.to_absolute('file:/a/base/path/')
    Nokogiri::HTML(absolute_html).css('img').first['src'].should == 'file:/a/base/path/images/lisa.jpg'
  end
  
  it 'should dehumanize strings' do
    'My new blog post!'.dehumanize.should == 'my-new-blog-post'
    'My 1rst blog post...'.dehumanize.should == 'my-1rst-blog-post'
  end
end